% This is the main driver program for simulating steady-state cardiac
% energetics of the control hearts under different work rates.
% Written by Fan Wu and Daniel Beard, Medical College of Wisconsin, 2008

clear;
setup;

global iPO2 idPsi iH_x iATP_x iADP_x iAMP_x iGTP_x iGDP_x iPI_x iNADH_x iQH2_x ...
       iOAA_x iACCOA_x iCIT_x iICIT_x iAKG_x iSCOA_x iCOASH_x iSUC_x iFUM_x ...
       iMAL_x iGLU_x iASP_x iK_x iMg_x iCO2tot_x iCred_i iATP_i iADP_i iAMP_i ...
       iPI_i iH_i iMg_i iK_i iATP_c iADP_c iPI_c iH_c iMg_c iK_c iPYR_x iPYR_i ...
       iPYR_c iCIT_i iCIT_c iAKG_i iAKG_c iSUC_i iSUC_c iMAL_i iMAL_c iASP_i ...
       iASP_c iGLU_i iGLU_c iFUM_i iFUM_c iICIT_i iICIT_c iPCr_c iAMP_c iCr_c;
     
global i_J_C1 i_J_C3 i_J_C4 i_J_F1 i_J_ANT i_J_PI1 i_J_Hle i_J_KH i_J_pdh i_J_cits ...
       i_J_acon i_J_isod i_J_akgd i_J_scoas i_J_sdh i_J_fum i_J_mdh i_J_ndk i_J_got ...
	     i_J_PI2 i_J_ATPt i_J_ADPt i_J_AMPt i_J_PYR_H i_J_GLU_H i_J_CIT_MAL i_J_SUC_MAL ... 
       i_J_AKG_MAL i_J_MAL_PI i_J_ASP_GLU i_J_PYRt i_J_CITt i_J_ICITt i_J_MALt ... 
	     i_J_AKGt i_J_SUCt i_J_FUMt i_J_GLUt i_J_ASPt i_J_CKe i_J_AKe i_J_AtC;

options = odeset('NonNegative', 1:62);

% iflag: 0 - normal; 1 - no oxygen consumption; 
%       8 - fixed PI_c; 9 - fixed ADP_c;
%       10 - no CK activity; 11 -
%       no CK and fixed PI_c; 12 - no CK and fixed ADP_c;
%       100 - constant J_AtC = x_AtC;
%       101 - constant J_AtC = x_AtC and fixed [CrP]c and [Cr]_c


%% Set up the initial conditions
% Run the simulation to steady states
iflag = 100;
[t,x] = ode15s(@Cell_dXdT,[0 5000],xo_con,options,param,x_AtC,iflag);

% Verify the results
xo_con = x(end,:);
CRtot_new = xo_con(iPCr_c)+xo_con(iCr_c); % per cyto water
ATPobs_BL_new = W_x*Rm_cell*xo_con(iATP_x) + W_i*Rm_cell*xo_con(iATP_i) + W_c*Rc_cell*xo_con(iATP_c) % per cell
CrPobs_BL_new = W_c*Rc_cell*xo_con(iPCr_c)
CrPobs_BL_new/ATPobs_BL_new
CrPobs_BL_new/ATPBL_cell


%% Generating simulations
Np = 30; % Setting up the number of steady-state outputs
for i = 1:Np
  i
  x_AtC(i) =  (i-1)*(0.8e-3)/10;  % mol s^{-1} (l cyto)^{-1}, ATP consumption rate
  iflag = 100;
  [t,x] = ode15s(@Cell_dXdT,[0 2000],x(end,:),options,param,x_AtC(i),iflag);
  Flux = [];
  for j = 1:length(t)
    Flux(j,:) = Cell_Flux(x(j,:),param,x_AtC(i));
  end
  x_st(i,:) = x(end,:);
  Flux_st(i,:) = Cell_Flux(x(end,:),param,x_AtC(i));
  
  % Computing MRS-observed signals from local concentrations
  PIobs(i)  = W_c*Rc_cell*x(end,iPI_c) + W_x*Rm_cell*x(end,iPI_x) + W_i*Rm_cell*x(end,iPI_i); 
  ATPobs(i) = W_c*Rc_cell*x(end,iATP_c) + W_x*Rm_cell*x(end,iATP_x) + W_i*Rm_cell*x(end,iATP_i);
  PCRobs(i) = W_c*Rc_cell*x(end,iPCr_c);
end

Rc_t = 0.73078; % ratio volume cell/volume tissue
Rm_cell = 0.288; 
rho = 1.05; % tissue density grams per ml
Flux_C4 = Flux_st(:,6); % Reaction fluxes on the mitochondrial complex IV
Flux_AtC = Flux_st(:,45);

% Converting the oxygen consumption rate from the Complex IV flux
MVO2_sim = (Flux_C4/2)*Rm_cell*Rc_t/(1000*rho)*60*1e6; % (umol O2) min-1 (g tissue)-1

% Computing the MRS-observed ratios
PCrATP_sim = PCRobs./ATPobs;
PCrATP_sim1 = PCRobs./ATPBL_cell;
PIPCr_sim = PIobs./PCRobs;

ADP_c = x_st(:,iADP_c);
ATP_c = x_st(:,iATP_c);
PI_c = x_st(:,iPI_c);

%% Finding out all concentration values at baseline
% Np  = 50; % Points of simulation
MVO2_BL = mean(MVO2_st_z([1 3:6 8:9 11 13:15])); % Finding out the average baseline MVO2
i_MVO2_BL = interp1(MVO2_sim,1:Np,MVO2_BL); % Finding out the location of MVO2
i_lb = floor(i_MVO2_BL); % find the lower bound of i_MVO2_BL 
i_ub = ceil(i_MVO2_BL); % find the upper bound of i_MVO2_BL 
% find the baseline J_AtC (mol s-1 (l cyto)^{-1}
Flux_AtC_lb = Flux_st(i_lb,45);
Flux_AtC_ub = Flux_st(i_ub,45);
Flux_AtC_BL = Flux_AtC_lb + (Flux_AtC_ub-Flux_AtC_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
J_AtC_BL = Flux_AtC_BL*0.6801;  % unit converted into (mol s-1 (l cell)^{-1})
% find the baseline [PI]_c (mol (l cyto water)-1)
PI_c_lb = x_st(i_lb,37);
PI_c_ub = x_st(i_ub,37);
PI_c_BL = PI_c_lb + (PI_c_ub-PI_c_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline [ADP]_c (mol (l cyto water)-1)
ADP_c_lb = x_st(i_lb,36);
ADP_c_ub = x_st(i_ub,36);
ADP_c_BL = ADP_c_lb + (ADP_c_ub-ADP_c_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline [PCr]_c (mol (l cyto water)-1)
PCr_c_lb = x_st(i_lb,60);
PCr_c_ub = x_st(i_ub,60);
PCr_c_BL = PCr_c_lb + (PCr_c_ub-PCr_c_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline [ATP]_c (mol (l cyto water)-1)
ATP_c_lb = x_st(i_lb,35);
ATP_c_ub = x_st(i_ub,35);
ATP_c_BL = ATP_c_lb + (ATP_c_ub-ATP_c_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline [ATP]_x (mol (l cyto water)-1)
ATP_x_lb = x_st(i_lb,4);
ATP_x_ub = x_st(i_ub,4);
ATP_x_BL = ATP_x_lb + (ATP_x_ub-ATP_x_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline PCr/ATP (observed) 
PCrATP_sim1_lb = PCrATP_sim1(i_lb);
PCrATP_sim1_ub = PCrATP_sim1(i_ub);
PCrATP_sim1_BL = PCrATP_sim1_lb + (PCrATP_sim1_ub-PCrATP_sim1_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);
% find the baseline PI/PCr (observed) 
PIPCr_sim_lb = PIPCr_sim(i_lb);
PIPCr_sim_ub = PIPCr_sim(i_ub);
PIPCr_sim_BL = PIPCr_sim_lb + (PIPCr_sim_ub-PIPCr_sim_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);

% find the basal and maxium dG_AtC value (DeltaG_crit)
dG_AtC_lb = Flux_st(i_lb,end);
dG_AtC_ub = Flux_st(i_ub,end);
dG_AtC_BL = dG_AtC_lb + (dG_AtC_ub-dG_AtC_lb)*(i_MVO2_BL-i_lb)/(i_ub-i_lb);

PI_c_BL*ADP_c_BL/ATP_c_BL

%% Finding out all concentration values at maximal MVO2
MVO2_max = max(MVO2_st_z); % Finding out the maximal MVO2
i_MVO2_max = interp1(MVO2_sim,1:Np,MVO2_max); % Finding out the location of MVO2
i_lb = floor(i_MVO2_max); % find the lower bound of i_MVO2_BL 
i_ub = ceil(i_MVO2_max); % find the upper bound of i_MVO2_BL 
% find the maximal J_AtC (mol s-1 (l cyto)-1)
Flux_AtC_lb = Flux_st(i_lb,45);
Flux_AtC_ub = Flux_st(i_ub,45);
Flux_AtC_max = Flux_AtC_lb + (Flux_AtC_ub-Flux_AtC_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
J_AtC_max = Flux_AtC_max*0.6801;  % unit converted into (mol s-1 (l cell)^{-1})
% find the maximal [PI]_c (mol (l cyto water)-1)
PI_c_lb = x_st(i_lb,37);
PI_c_ub = x_st(i_ub,37);
PI_c_max = PI_c_lb + (PI_c_ub-PI_c_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
% find the maximal [ADP]_c (mol (l cyto water)-1)
ADP_c_lb = x_st(i_lb,36);
ADP_c_ub = x_st(i_ub,36);
ADP_c_max = ADP_c_lb + (ADP_c_ub-ADP_c_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
% find the maximal [PCr]_c (mol (l cyto water)-1)
PCr_c_lb = x_st(i_lb,60);
PCr_c_ub = x_st(i_ub,60);
PCr_c_max = PCr_c_lb + (PCr_c_ub-PCr_c_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
% find the maximal [ATP]_c (mol (l cyto water)-1)
ATP_c_lb = x_st(i_lb,35);
ATP_c_ub = x_st(i_ub,35);
ATP_c_max = ATP_c_lb + (ATP_c_ub-ATP_c_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
% find the maximal [ATP]_x (mol (l cyto water)-1)
ATP_x_lb = x_st(i_lb,4);
ATP_x_ub = x_st(i_ub,4);
ATP_x_max = ATP_x_lb + (ATP_x_ub-ATP_x_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);
% find the maximal PCr/ATP (observed) 
PCrATP_sim1_lb = PCrATP_sim1(i_lb);
PCrATP_sim1_ub = PCrATP_sim1(i_ub);
PCrATP_sim1_max = PCrATP_sim1_lb + (PCrATP_sim1_ub-PCrATP_sim1_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);

dG_AtC_lb = Flux_st(i_lb,end);
dG_AtC_ub = Flux_st(i_ub,end);
dG_AtC_max = dG_AtC_lb + (dG_AtC_ub-dG_AtC_lb)*(i_MVO2_max-i_lb)/(i_ub-i_lb);

PI_c_max*ADP_c_max/ATP_c_max

%% save results of the control simulation
save steady_states_control.mat;

